%define anolis_release 1
%global __cmake_in_source_build 1
Name:           snappy
Version:        1.1.10
Release:        %{anolis_release}%{?dist}
Summary:        Fast compression and decompression library

License:        BSD
URL:            https://github.com/google/snappy
Source0:	https://github.com/google/snappy/archive/refs/tags/%{version}.tar.gz

# Remove dependency on bundled gtest and google-benchmark.
Patch0:         %{name}-thirdparty.patch
Patch1:         %{name}-do-not-disable-rtti.patch

BuildRequires:  make
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  google-benchmark-devel
BuildRequires:  gtest-devel

%description
Snappy is a compression/decompression library. It does not aim for maximum 
compression, or compatibility with any other compression library; instead, it 
aims for very high speeds and reasonable compression. For instance, compared to 
the fastest mode of zlib, Snappy is an order of magnitude faster for most 
inputs, but the resulting compressed files are anywhere from 20% to 100% 
bigger. 

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       cmake-filesystem
Requires:       pkgconfig

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup

%build
%cmake -DCMAKE_CXX_STANDARD=14 .
%make_build

# create pkgconfig file
cat << EOF >snappy.pc
prefix=%{_prefix}
exec_prefix=%{_exec_prefix}
includedir=%{_includedir}
libdir=%{_libdir}

Name: %{name}
Description: A fast compression/decompression library
Version: %{version}
Cflags: -I\${includedir}
Libs: -L\${libdir} -lsnappy
EOF


%install
rm -rf %{buildroot}
chmod 644 *.txt AUTHORS COPYING NEWS README.md
%make_install
install -m644 -D snappy.pc %{buildroot}%{_libdir}/pkgconfig/snappy.pc
rm -rf %{buildroot}%{_datadir}/doc/snappy/
rm -rf %{buildroot}%{_datadir}/doc/snappy-devel/

%check
ctest -V %{?_smp_mflags}


%ldconfig_scriptlets

%generate_compatibility_deps

%files
%license COPYING
%{_libdir}/libsnappy.so.*
%dir %{abidir}
%{abidir}/libsnappy.dump

%files doc
%doc AUTHORS NEWS README.md CONTRIBUTING.md

%files devel
%doc format_description.txt framing_format.txt
%{_includedir}/snappy*.h
%{_libdir}/libsnappy.so
%{_libdir}/pkgconfig/snappy.pc
%{_libdir}/cmake/Snappy/

%changelog
* Tue Mar 28 2023 happy_orange <songnannan@linux.alibaba.com> - 1.1.10-1
- update to 1.1.10

* Mon Feb 13 2023 Jing Zhang <renyu.zj@linux.alibaba.com> - 1.1.9-3
- optimize spec

* Thu Sep 29 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.1.9-2
- add doc package

* Fri Mar 11 2022 Mingyue Zhao <wb-zmy745940@alibaba-inc.com> - 1.1.9-1
- Init for Anolis OS 23
